import Vue from 'vue';
import addFormats from 'ajv-formats';
import VueFormJsonSchema, { vfjsFieldMixin } from 'vue-form-json-schema';
import Cropper from 'cropperjs';
import { throttle } from 'lodash';

/*
 * src/schema-utils.js
 * Created: Wed May 26 2021 23:59:13 GMT+0530 (India Standard Time)
 * Copyright 2021 Harish Karumuthil<harish2704@gmail.com>
 */

const defaultFields = {};

defaultFields.input = function (name, schema) {
  return Object.assign({
    component: "app-input",
    model: name
  }, schema.ui);
};

defaultFields.select = function (name, schema) {
  return Object.assign({
    component: "app-select",
    model: name,
    enum: schema.enum
  }, schema.ui);
};

defaultFields.array = function (name, schema) {
  return Object.assign({
    component: "app-array-container",
    model: name,
    children: Object.entries(schema.properties).map(([name, schema]) => defaultFields.default(name, schema))
  }, schema.ui);
};

defaultFields.default = function (name, schema) {
  switch (schema.type) {
    case "array":
      return defaultFields.array(name, schema.items);

    default:
      if (schema.enum !== undefined) {
        return defaultFields.select(name, schema);
      }

      return defaultFields.input(name, schema);
  }
};

function getUiSchema(lightSchema) {
  return Object.entries(lightSchema.properties).map(([name, schema]) => defaultFields.default(name, schema));
}

function getJsonSchemaField(field) {
  let out;

  switch (field.type) {
    case "object":
      return getJsonSchema(field);

    case "array":
      return field.items.map(getJsonSchemaField);

    default:
      out = Object.assign({}, field, {
        ui: undefined
      });

      if (out.enum && typeof out.enum[0] === "object") {
        out.enum = out.enum.map(v => v.value);
      }

      return out;
  }
}

function getJsonSchema(fullSchema) {
  const out = Object.assign({}, fullSchema);
  out.properties = Object.assign({}, fullSchema.properties);
  const properties = out.properties;

  for (const key in properties) {
    properties[key] = getJsonSchemaField(properties[key]);
  }

  return out;
}

var schemaUtils = {
  defaultFields,
  getUiSchema,
  getJsonSchema
};

//
var script$7 = {
  mixins: [vfjsFieldMixin],
  methods: {
    id(index) {
      return `${this.vfjsFieldId}-${index}`;
    },

    onChange(index, model) {
      const newModel = this.vfjsFieldModel.slice();
      newModel[index] = model;
      this.setModel(newModel);
    },

    appendItem() {
      this.setModel((this.vfjsFieldModel || []).concat([{}]));
    },

    clone(index) {
      const newData = this.vfjsFieldModel.slice();
      newData.splice(index, 0, { ...this.vfjsFieldModel[index]
      });
      this.setModel(newData);
    },

    remove(index) {
      this.vfjsFieldModel.splice(index, 1);
      this.setModel(this.vfjsFieldModel.slice());
    }

  }
};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    const options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    let hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            const originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            const existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

/* script */
const __vue_script__$7 = script$7;
/* template */

var __vue_render__$7 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('fieldset', [_c('legend', [_vm._v("\n    Item list: " + _vm._s(_vm.vfjsFieldModelKey) + "\n    "), _c('button', {
    attrs: {
      "type": "button"
    },
    on: {
      "click": _vm.appendItem
    }
  }, [_vm._v("add")])]), _vm._v(" "), _c('table', _vm._l(_vm.vfjsFieldModel, function (model, index) {
    return _c('tr', {
      key: index
    }, [_c('td', [_c('vue-form-json-schema', {
      attrs: {
        "schema": _vm.vfjsFieldSchema.items,
        "ui-schema": _vm.vfjsChildrenUiSchema,
        "model": model,
        "id": _vm.id(index),
        "options": _vm.vfjsOptions
      },
      on: {
        "change": function (v) {
          return _vm.onChange(index, v);
        }
      }
    })], 1), _vm._v(" "), _c('td', [_c('button', {
      attrs: {
        "type": "button"
      },
      on: {
        "click": function ($event) {
          return _vm.remove(index);
        }
      }
    }, [_vm._v("remove")]), _vm._v(" "), _c('button', {
      attrs: {
        "type": "button"
      },
      on: {
        "click": function ($event) {
          return _vm.clone(index);
        }
      }
    }, [_vm._v("clone")])])]);
  }), 0)]);
};

var __vue_staticRenderFns__$7 = [];
/* style */

const __vue_inject_styles__$7 = undefined;
/* scoped */

const __vue_scope_id__$7 = undefined;
/* module identifier */

const __vue_module_identifier__$7 = undefined;
/* functional template */

const __vue_is_functional_template__$7 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$7 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$7,
  staticRenderFns: __vue_staticRenderFns__$7
}, __vue_inject_styles__$7, __vue_script__$7, __vue_scope_id__$7, __vue_is_functional_template__$7, __vue_module_identifier__$7, false, undefined, undefined, undefined);

//
var script$6 = {
  name: "AvatarCropper",
  props: {
    trigger: {
      type: [String],
      required: true
    },
    uploadHandler: {
      type: Function
    },
    uploadUrl: {
      type: String
    },
    requestMethod: {
      type: String,
      default: "POST"
    },
    uploadHeaders: {
      type: Object
    },
    uploadFormName: {
      type: String,
      default: "file"
    },
    uploadFormData: {
      type: Object,

      default() {
        return {};
      }

    },
    cropperOptions: {
      type: Object,

      default() {
        return {
          aspectRatio: 1,
          autoCropArea: 1,
          viewMode: 1,
          movable: false,
          zoomable: false
        };
      }

    },
    outputOptions: {
      type: Object
    },
    outputMime: {
      type: String,
      default: null
    },
    outputQuality: {
      type: Number,
      default: 0.9
    },
    mimes: {
      type: String,
      default: "image/png, image/gif, image/jpeg, image/bmp, image/x-icon"
    },
    labels: {
      type: Object,

      default() {
        return {
          submit: "Submit",
          cancel: "Cancel"
        };
      }

    },
    withCredentials: {
      type: Boolean,
      default: false
    },
    inline: {
      type: Boolean,
      default: false
    }
  },

  data() {
    return {
      cropper: undefined,
      dataUrl: undefined,
      filename: undefined
    };
  },

  methods: {
    destroy() {
      if (this.cropper) {
        this.cropper.destroy();
      }

      this.$refs.input.value = "";
      this.dataUrl = undefined;
    },

    submit() {
      this.$emit("submit");

      if (this.uploadUrl) {
        this.uploadImage();
      } else if (this.uploadHandler) {
        this.uploadHandler(this.cropper);
      } else {
        this.$emit("error", "No upload handler found.", "user");
      }

      this.destroy();
    },

    cancel() {
      this.$emit("cancel");
      this.destroy();
    },

    pickImage(e) {
      this.$refs.input.click();
      e.preventDefault();
      e.stopPropagation();
    },

    createCropper() {
      this.cropper = new Cropper(this.$refs.img, this.cropperOptions);
    },

    uploadImage() {
      this.cropper.getCroppedCanvas(this.outputOptions).toBlob(blob => {
        let form = new FormData();
        let xhr = new XMLHttpRequest();
        let data = Object.assign({}, this.uploadFormData);
        xhr.withCredentials = this.withCredentials;

        for (let key in data) {
          form.append(key, data[key]);
        }

        form.append(this.uploadFormName, blob, this.filename);
        this.$emit("uploading", form, xhr);
        xhr.open(this.requestMethod, this.uploadUrl, true);

        for (let header in this.uploadHeaders) {
          xhr.setRequestHeader(header, this.uploadHeaders[header]);
        }

        xhr.onreadystatechange = () => {
          if (xhr.readyState === 4) {
            let response = "";

            try {
              response = JSON.parse(xhr.responseText);
            } catch (err) {
              response = xhr.responseText;
            }

            this.$emit("completed", response, form, xhr);

            if ([200, 201, 204].indexOf(xhr.status) > -1) {
              this.$emit("uploaded", response, form, xhr);
            } else {
              this.$emit("error", "Image upload fail.", "upload", xhr);
            }
          }
        };

        xhr.send(form);
      }, this.outputMime, this.outputQuality);
    }

  },

  mounted() {
    // listen for click event on trigger
    let trigger = typeof this.trigger == "object" ? this.trigger : document.querySelector(this.trigger);

    if (!trigger) {
      this.$emit("error", "No avatar make trigger found.", "user");
    } else {
      trigger.addEventListener("click", this.pickImage);
    } // listen for input file changes


    let fileInput = this.$refs.input;
    fileInput.addEventListener("change", () => {
      if (fileInput.files != null && fileInput.files[0] != null) {
        let correctType = this.mimes.split(", ").find(m => m === fileInput.files[0].type);

        if (!correctType) {
          this.$emit("error", "File type not correct.", "user");
          return;
        }

        let reader = new FileReader();

        reader.onload = e => {
          this.dataUrl = e.target.result;
        };

        reader.readAsDataURL(fileInput.files[0]);
        this.filename = fileInput.files[0].name || "unknown";
        this.mimeType = this.mimeType || fileInput.files[0].type;
        this.$emit("changed", fileInput.files[0], reader);
      }
    });
  }

};

/* script */
const __vue_script__$6 = script$6;
/* template */

var __vue_render__$6 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "avatar-cropper"
  }, [_vm.dataUrl ? _c('div', {
    staticClass: "avatar-cropper-overlay",
    class: {
      'avatar-cropper-overlay-inline': _vm.inline
    }
  }, [!_vm.inline ? _c('div', {
    staticClass: "avatar-cropper-mark"
  }, [_c('a', {
    staticClass: "avatar-cropper-close",
    attrs: {
      "title": _vm.labels.cancel,
      "href": "javascript:;"
    },
    on: {
      "click": _vm.cancel
    }
  }, [_vm._v("×")])]) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "avatar-cropper-container"
  }, [_c('div', {
    staticClass: "avatar-cropper-image-container"
  }, [_c('img', {
    ref: "img",
    attrs: {
      "src": _vm.dataUrl,
      "alt": ""
    },
    on: {
      "load": function ($event) {
        $event.stopPropagation();
        return _vm.createCropper.apply(null, arguments);
      }
    }
  })]), _vm._v(" "), _c('div', {
    staticClass: "avatar-cropper-footer"
  }, [_c('button', {
    staticClass: "avatar-cropper-btn",
    on: {
      "click": function ($event) {
        $event.stopPropagation();
        $event.preventDefault();
        return _vm.cancel.apply(null, arguments);
      }
    }
  }, [_vm._v("\n          Cancel\n        ")]), _vm._v(" "), _c('button', {
    staticClass: "avatar-cropper-btn",
    on: {
      "click": function ($event) {
        $event.stopPropagation();
        $event.preventDefault();
        return _vm.submit.apply(null, arguments);
      }
    }
  }, [_vm._v("\n          Submit\n        ")])])])]) : _vm._e(), _vm._v(" "), _c('input', {
    ref: "input",
    staticClass: "avatar-cropper-img-input",
    attrs: {
      "accept": _vm.mimes,
      "type": "file"
    }
  })]);
};

var __vue_staticRenderFns__$6 = [];
/* style */

const __vue_inject_styles__$6 = undefined;
/* scoped */

const __vue_scope_id__$6 = undefined;
/* module identifier */

const __vue_module_identifier__$6 = undefined;
/* functional template */

const __vue_is_functional_template__$6 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$6 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$6,
  staticRenderFns: __vue_staticRenderFns__$6
}, __vue_inject_styles__$6, __vue_script__$6, __vue_scope_id__$6, __vue_is_functional_template__$6, __vue_module_identifier__$6, false, undefined, undefined, undefined);

//
var script$5 = {
  mixins: [vfjsFieldMixin],

  data() {
    return {
      tmpSelectedPhoto: ""
    };
  },

  components: {
    AvatarCropper: __vue_component__$6
  },
  computed: {
    imageUrl() {
      const model = this.vfjsFieldModel;

      if (model instanceof Blob) {
        return URL.createObjectURL(model);
      }

      return "";
    }

  },
  methods: {
    onInput: function (value) {
      const val = this.vfjsFieldSchema.type === "boolean" ? value : value;
      this.setModel(val);
    },

    photoCancelHandler() {
      this.tmpSelectedPhoto = "";
    },

    photoChangedHandler(fileInput) {
      this.tmpSelectedPhoto = fileInput.name;
    },

    photoUploadHandler(cropper) {
      cropper.getCroppedCanvas({
        width: 512,
        height: 512
      }).toBlob(blob => {
        this.setModel(blob);
      }, "image/jpeg", 0.9);
    }

  }
};

/* script */
const __vue_script__$5 = script$5;
/* template */

var __vue_render__$5 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "form-group"
  }, [_c('div', {
    staticClass: "input-group mb-3",
    attrs: {
      "id": "pick-avatar"
    }
  }, [_c('input', {
    directives: [{
      name: "model",
      rawName: "v-model",
      value: _vm.tmpSelectedPhoto,
      expression: "tmpSelectedPhoto"
    }],
    staticClass: "form-control",
    attrs: {
      "type": "text",
      "readonly": "",
      "placeholder": _vm.vfjsFieldSchema.title || _vm.vfjsFieldModelKey
    },
    domProps: {
      "value": _vm.tmpSelectedPhoto
    },
    on: {
      "input": function ($event) {
        if ($event.target.composing) {
          return;
        }

        _vm.tmpSelectedPhoto = $event.target.value;
      }
    }
  }), _vm._v(" "), _c('input', {
    directives: [{
      name: "model",
      rawName: "v-model",
      value: _vm.tmpSelectedPhoto,
      expression: "tmpSelectedPhoto"
    }],
    staticClass: "custom-control-input",
    attrs: {
      "type": "text",
      "name": "tmpSelectedPhoto",
      "required": _vm.vfjsFieldRequired
    },
    domProps: {
      "value": _vm.tmpSelectedPhoto
    },
    on: {
      "input": function ($event) {
        if ($event.target.composing) {
          return;
        }

        _vm.tmpSelectedPhoto = $event.target.value;
      }
    }
  }), _vm._v(" "), _vm._m(0)]), _vm._v(" "), _vm.vfjsFieldModel ? _c('img', {
    staticClass: "rounded img-thumbnail img-fluid mx-auto d-block",
    attrs: {
      "width": "200",
      "src": _vm.imageUrl,
      "alt": "Preview"
    }
  }) : _vm._e(), _vm._v(" "), _c('AvatarCropper', {
    attrs: {
      "trigger": "#pick-avatar",
      "upload-handler": _vm.photoUploadHandler
    },
    on: {
      "changed": _vm.photoChangedHandler,
      "cancel": _vm.photoCancelHandler
    }
  })], 1);
};

var __vue_staticRenderFns__$5 = [function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "input-group-append"
  }, [_c('span', {
    staticClass: "input-group-text",
    attrs: {
      "id": "basic-addon2"
    }
  }, [_vm._v("Browse")])]);
}];
/* style */

const __vue_inject_styles__$5 = undefined;
/* scoped */

const __vue_scope_id__$5 = undefined;
/* module identifier */

const __vue_module_identifier__$5 = undefined;
/* functional template */

const __vue_is_functional_template__$5 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$5 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$5,
  staticRenderFns: __vue_staticRenderFns__$5
}, __vue_inject_styles__$5, __vue_script__$5, __vue_scope_id__$5, __vue_is_functional_template__$5, __vue_module_identifier__$5, false, undefined, undefined, undefined);

/*
 * src/mixins.js
 * Created: Thu May 27 2021 23:28:58 GMT+0530 (India Standard Time)
 * Copyright 2021 Harish Karumuthil<harish2704@gmail.com>
 */

function computedPlaceholder() {
  return "Enter " + this.computedLabel;
}

function computedLabel() {
  return this.vfjsFieldSchema.title || this.vfjsFieldModelKey;
}

function computedHelpId() {
  return this.vfjsFieldId + "-help";
}

function computedErrorClass() {
  return this.vfjsComputedFieldHasErrors ? "invalid" : "valid";
}

function computedErrorMessage() {
  return this.vfjsFieldErrors[0] && this.vfjsFieldErrors[0].message;
}

function onInput($event) {
  const val = this.vfjsFieldSchema.type === "boolean" ? $event.target.checked : $event.target.value;
  this.setModel(val);
}

const onInputThrottled = throttle(onInput, 500);
var appMixins = {
  computed: {
    computedLabel,
    computedPlaceholder,
    computedHelpId,
    computedErrorClass,
    computedErrorMessage
  },
  methods: {
    onInput,
    onInputThrottled
  }
};

//

const schemaTypeInputTypeMap = {
  integer: "number",
  boolean: "checkbox"
};
const schemaFormatInputTypeMap = {
  email: "email"
};
var script$4 = {
  mixins: [vfjsFieldMixin, appMixins],
  computed: {
    inputType() {
      return this.vfjsFieldUiSchema.type || schemaFormatInputTypeMap[this.vfjsFieldSchema.format] || schemaTypeInputTypeMap[this.vfjsFieldSchema.type] || "text";
    }

  }
};

/* script */
const __vue_script__$4 = script$4;
/* template */

var __vue_render__$4 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "form-group"
  }, [_c('label', {
    attrs: {
      "for": _vm.vfjsFieldId
    }
  }, [_vm._v(_vm._s(_vm.computedLabel))]), _vm._v(" "), _c('input', {
    class: 'form-control is-' + _vm.computedErrorClass,
    attrs: {
      "id": _vm.vfjsFieldId,
      "placeholder": _vm.computedPlaceholder,
      "name": _vm.vfjsFieldModelKey,
      "type": _vm.inputType,
      "required": _vm.vfjsFieldRequired,
      "aria-describedby": _vm.computedHelpId
    },
    domProps: {
      "value": _vm.vfjsFieldModel
    },
    on: {
      "input": _vm.onInputThrottled
    }
  }), _vm._v(" "), _c('div', {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.vfjsComputedShowFieldErrors,
      expression: "vfjsComputedShowFieldErrors"
    }],
    class: _vm.computedErrorClass + '-feedback'
  }, [_vm._v("\n    " + _vm._s(_vm.computedErrorMessage) + "\n  ")]), _vm._v(" "), _c('small', {
    staticClass: "form-text text-muted",
    attrs: {
      "id": _vm.computedHelpId
    }
  }, [_vm._v("\n    " + _vm._s(_vm.vfjsFieldSchema.description) + "\n  ")])]);
};

var __vue_staticRenderFns__$4 = [];
/* style */

const __vue_inject_styles__$4 = undefined;
/* scoped */

const __vue_scope_id__$4 = undefined;
/* module identifier */

const __vue_module_identifier__$4 = undefined;
/* functional template */

const __vue_is_functional_template__$4 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$4 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$4,
  staticRenderFns: __vue_staticRenderFns__$4
}, __vue_inject_styles__$4, __vue_script__$4, __vue_scope_id__$4, __vue_is_functional_template__$4, __vue_module_identifier__$4, false, undefined, undefined, undefined);

//
var script$3 = {
  mixins: [vfjsFieldMixin, appMixins],
  computed: {
    options() {
      const options = this.vfjsFieldUiSchema.enum || this.vfjsFieldSchema.enum || [];
      return options;
    }

  }
};

/* script */
const __vue_script__$3 = script$3;
/* template */

var __vue_render__$3 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('fieldset', {
    staticClass: "form-group"
  }, [_c('legend', {
    staticClass: "col-form-label"
  }, [_vm._v(_vm._s(_vm.computedLabel))]), _vm._v(" "), _vm._l(_vm.options, function (opt) {
    return _c('div', {
      key: opt.value,
      class: 'form-check form-check-inline is-' + _vm.computedErrorClass
    }, [_c('input', {
      staticClass: "form-check-input",
      attrs: {
        "type": "radio",
        "name": _vm.vfjsFieldModelKey,
        "id": _vm.vfjsFieldId + opt.value,
        "required": _vm.vfjsFieldRequired,
        "aria-describedby": _vm.computedHelpId
      },
      domProps: {
        "checked": _vm.vfjsFieldModel == opt.value,
        "value": opt.value
      },
      on: {
        "input": _vm.onInput
      }
    }), _vm._v(" "), _c('label', {
      staticClass: "form-check-label",
      attrs: {
        "for": _vm.vfjsFieldId + opt.value
      }
    }, [_vm._v("\n      " + _vm._s(opt.text || opt) + "\n    ")])]);
  }), _vm._v(" "), _c('div', {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.vfjsComputedShowFieldErrors,
      expression: "vfjsComputedShowFieldErrors"
    }],
    class: _vm.computedErrorClass + '-feedback'
  }, [_vm._v("\n    " + _vm._s(_vm.computedErrorMessage) + "\n  ")]), _vm._v(" "), _c('small', {
    staticClass: "form-text text-muted",
    attrs: {
      "id": _vm.computedHelpId
    }
  }, [_vm._v("\n    " + _vm._s(_vm.vfjsFieldSchema.description) + "\n  ")])], 2);
};

var __vue_staticRenderFns__$3 = [];
/* style */

const __vue_inject_styles__$3 = undefined;
/* scoped */

const __vue_scope_id__$3 = undefined;
/* module identifier */

const __vue_module_identifier__$3 = undefined;
/* functional template */

const __vue_is_functional_template__$3 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$3 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$3,
  staticRenderFns: __vue_staticRenderFns__$3
}, __vue_inject_styles__$3, __vue_script__$3, __vue_scope_id__$3, __vue_is_functional_template__$3, __vue_module_identifier__$3, false, undefined, undefined, undefined);

//
var script$2 = {
  mixins: [vfjsFieldMixin, appMixins],
  computed: {
    options() {
      const options = this.vfjsFieldUiSchema.enum || this.vfjsFieldSchema.enum || [];

      if (options[0] !== undefined && typeof options[0] !== 'object') {
        return options.map(v => {
          return {
            text: v,
            value: v
          };
        });
      }

      return options;
    }

  }
};

/* script */
const __vue_script__$2 = script$2;
/* template */

var __vue_render__$2 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "form-group"
  }, [_c('label', {
    attrs: {
      "for": _vm.vfjsFieldId
    }
  }, [_vm._v(_vm._s(_vm.computedLabel))]), _vm._v(" "), _c('select', {
    class: 'form-control is-' + _vm.computedErrorClass,
    attrs: {
      "id": _vm.vfjsFieldId,
      "placeholder": _vm.computedPlaceholder,
      "name": _vm.vfjsFieldModelKey,
      "required": _vm.vfjsFieldRequired,
      "aria-describedby": _vm.computedHelpId
    },
    domProps: {
      "value": _vm.vfjsFieldModel
    },
    on: {
      "input": _vm.onInput
    }
  }, [_c('option', {
    domProps: {
      "value": undefined
    }
  }, [_vm._v("\n      -- Please select --\n    ")]), _vm._v(" "), _vm._l(_vm.options, function (opt) {
    return _c('option', {
      key: opt.value,
      domProps: {
        "value": opt.value
      }
    }, [_vm._v("\n      " + _vm._s(opt.text) + "\n    ")]);
  })], 2), _vm._v(" "), _c('div', {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.vfjsComputedShowFieldErrors,
      expression: "vfjsComputedShowFieldErrors"
    }],
    class: _vm.computedErrorClass + '-feedback'
  }, [_vm._v("\n    " + _vm._s(_vm.computedErrorMessage) + "\n  ")]), _vm._v(" "), _c('small', {
    staticClass: "form-text text-muted",
    attrs: {
      "id": _vm.computedHelpId
    }
  }, [_vm._v("\n    " + _vm._s(_vm.vfjsFieldSchema.description) + "\n  ")])]);
};

var __vue_staticRenderFns__$2 = [];
/* style */

const __vue_inject_styles__$2 = undefined;
/* scoped */

const __vue_scope_id__$2 = undefined;
/* module identifier */

const __vue_module_identifier__$2 = undefined;
/* functional template */

const __vue_is_functional_template__$2 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$2 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$2,
  staticRenderFns: __vue_staticRenderFns__$2
}, __vue_inject_styles__$2, __vue_script__$2, __vue_scope_id__$2, __vue_is_functional_template__$2, __vue_module_identifier__$2, false, undefined, undefined, undefined);

//
var script$1 = {
  name: "select-component",
  mixins: [vfjsFieldMixin, appMixins]
};

/* script */
const __vue_script__$1 = script$1;
/* template */

var __vue_render__$1 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "form-group"
  }, [_c('label', {
    attrs: {
      "for": _vm.vfjsFieldId
    }
  }, [_vm._v(_vm._s(_vm.computedLabel))]), _vm._v(" "), _c('textarea', {
    class: 'form-control is-' + _vm.computedErrorClass,
    attrs: {
      "id": _vm.vfjsFieldId,
      "name": _vm.vfjsFieldModelKey,
      "placeholder": _vm.computedPlaceholder,
      "required": _vm.vfjsFieldRequired,
      "aria-describedby": _vm.computedHelpId
    },
    domProps: {
      "value": _vm.vfjsFieldModel
    },
    on: {
      "input": _vm.onInputThrottled
    }
  }), _vm._v(" "), _c('div', {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.vfjsComputedShowFieldErrors,
      expression: "vfjsComputedShowFieldErrors"
    }],
    class: _vm.computedErrorClass + '-feedback'
  }, [_vm._v("\n    " + _vm._s(_vm.computedErrorMessage) + "\n  ")]), _vm._v(" "), _c('small', {
    staticClass: "form-text text-muted",
    attrs: {
      "id": _vm.computedHelpId
    }
  }, [_vm._v("\n    " + _vm._s(_vm.vfjsFieldSchema.description) + "\n  ")])]);
};

var __vue_staticRenderFns__$1 = [];
/* style */

const __vue_inject_styles__$1 = undefined;
/* scoped */

const __vue_scope_id__$1 = undefined;
/* module identifier */

const __vue_module_identifier__$1 = undefined;
/* functional template */

const __vue_is_functional_template__$1 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$1 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$1,
  staticRenderFns: __vue_staticRenderFns__$1
}, __vue_inject_styles__$1, __vue_script__$1, __vue_scope_id__$1, __vue_is_functional_template__$1, __vue_module_identifier__$1, false, undefined, undefined, undefined);

//
Vue.component("AppArrayContainer", __vue_component__$7);
Vue.component("AppImageSelect", __vue_component__$5);
Vue.component("AppInput", __vue_component__$4);
Vue.component("AppRadioSelect", __vue_component__$3);
Vue.component("AppSelect", __vue_component__$2);
Vue.component("AppTextarea", __vue_component__$1);

const formOptions = () => {
  return {
    showValidationErrors: true,
    castToSchemaType: true,
    validateOnLoad: false,
    ajv: {
      plugins: [addFormats],
      options: {
        strict: false,
        strictSchema: false
      }
    }
  };
};

var script = {
  props: {
    options: {
      type: Object,
      default: formOptions
    },
    schema: Object,
    value: Object
  },
  computed: {
    uiSchema() {
      return schemaUtils.getUiSchema(this.schema);
    },

    jsonSchema() {
      return schemaUtils.getJsonSchema(this.schema);
    }

  },
  components: {
    VueFormJsonSchema
  },
  methods: {
    onChange(args) {
      this.$emit("input", args);
    }

  }
};

/* script */
const __vue_script__ = script;
/* template */

var __vue_render__ = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', [_c('VueFormJsonSchema', {
    attrs: {
      "options": _vm.options,
      "uiSchema": _vm.uiSchema,
      "schema": _vm.jsonSchema,
      "value": _vm.value
    },
    on: {
      "change": _vm.onChange
    }
  })], 1);
};

var __vue_staticRenderFns__ = [];
/* style */

const __vue_inject_styles__ = undefined;
/* scoped */

const __vue_scope_id__ = undefined;
/* module identifier */

const __vue_module_identifier__ = undefined;
/* functional template */

const __vue_is_functional_template__ = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__ = /*#__PURE__*/normalizeComponent({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

var components = /*#__PURE__*/Object.freeze({
  __proto__: null,
  HkForm: __vue_component__
});

// Import vue components

const install = function installHkFormBootstrap(Vue) {
  Object.entries(components).forEach(([componentName, component]) => {
    Vue.component(componentName, component);
  });
}; // Create module definition for Vue.use()

export default install;
export { __vue_component__ as HkForm };
